]> git.ipfire.org Git - thirdparty/bash.git/blobdiff - pathexp.h
fix for SIGINT in sourced script
[thirdparty/bash.git] / pathexp.h
index 7ddd17ac47004a78cc8b9329f718688bb3084f13..183a2124c9d10115b79f8fbf595840741559beaa 100644 (file)
--- a/pathexp.h
+++ b/pathexp.h
@@ -1,22 +1,22 @@
 /* pathexp.h -- The shell interface to the globbing library. */
 
-/* Copyright (C) 1987,1989 Free Software Foundation, Inc.
+/* Copyright (C) 1987-2015 Free Software Foundation, Inc.
 
    This file is part of GNU Bash, the Bourne Again SHell.
 
-   Bash is free software; you can redistribute it and/or modify it under
-   the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 2, or (at your option) any later
-   version.
+   Bash is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-   Bash is distributed in the hope that it will be useful, but WITHOUT ANY
-   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-   for more details.
+   Bash is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License along
-   with Bash; see the file COPYING.  If not, write to the Free Software
-   Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
+   You should have received a copy of the GNU General Public License
+   along with Bash.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 #if !defined (_PATHEXP_H_)
 #define _PATHEXP_H_
@@ -32,17 +32,23 @@ extern char *glob_error_return;
 /* Flag values for quote_string_for_globbing */
 #define QGLOB_CVTNULL  0x01    /* convert QUOTED_NULL strings to '\0' */
 #define QGLOB_FILENAME 0x02    /* do correct quoting for matching filenames */
+#define QGLOB_REGEXP   0x04    /* quote an ERE for regcomp/regexec */
 
 #if defined (EXTENDED_GLOB)
-/* Flags to OR with other flag args to fnmatch() to enabled the extended
+/* Flags to OR with other flag args to strmatch() to enabled the extended
    pattern matching. */
 #  define FNMATCH_EXTFLAG      (extended_glob ? FNM_EXTMATCH : 0)
 #else
 #  define FNMATCH_EXTFLAG      0
 #endif /* !EXTENDED_GLOB */
 
+#define FNMATCH_IGNCASE                (match_ignore_case ? FNM_CASEFOLD : 0)
+#define FNMATCH_NOCASEGLOB     (glob_ignore_case ? FNM_CASEFOLD : 0)
+
 extern int glob_dot_filenames;
 extern int extended_glob;
+extern int glob_star;
+extern int match_ignore_case;  /* doesn't really belong here */
 
 extern int unquoted_glob_pattern_p __P((char *));
 
@@ -56,15 +62,16 @@ extern int unquoted_glob_pattern_p __P((char *));
    pattern while executing a case statement), flags should include
    QGLOB_CVTNULL.  If flags includes QGLOB_FILENAME, appropriate quoting
    to match a filename should be performed. */
-extern char *quote_string_for_globbing __P((char *, int));
+extern char *quote_string_for_globbing __P((const char *, int));
 
-extern char *quote_globbing_chars __P((char *));
+extern int glob_char_p __P((const char *));
+extern char *quote_globbing_chars __P((const char *));
 
 /* Call the glob library to do globbing on PATHNAME. */
-extern char **shell_glob_filename __P((char *));
+extern char **shell_glob_filename __P((const char *));
 
-/* Filename completion ignore.  Used to the "fignore" facility of
-   tcsh and GLOBIGNORE (like ksh-93 FIGNORE).
+/* Filename completion ignore.  Used to implement the "fignore" facility of
+   tcsh, GLOBIGNORE (like ksh-93 FIGNORE), and EXECIGNORE.
 
    It is passed a NULL-terminated array of (char *)'s that must be
    free()'d if they are deleted.  The first element (names[0]) is the
@@ -77,12 +84,14 @@ struct ign {
   int len, flags;
 };
 
+typedef int sh_iv_item_func_t __P((struct ign *));
+
 struct ignorevar {
-  char *varname;       /* FIGNORE or GLOBIGNORE */
+  char *varname;       /* FIGNORE, GLOBIGNORE, or EXECIGNORE */
   struct ign *ignores; /* Store the ignore strings here */
   int num_ignores;     /* How many are there? */
   char *last_ignoreval;        /* Last value of variable - cached for speed */
-  Function *item_func; /* Called when each item is parsed from $`varname' */
+  sh_iv_item_func_t *item_func; /* Called when each item is parsed from $`varname' */
 };
 
 extern void setup_ignore_patterns __P((struct ignorevar *));